@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 1997--2015 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 1997--2022 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,16 +31,16 @@ Event_iterator::Event_iterator ()
 }
 
 void
-Event_iterator::construct_children ()
+Event_iterator::create_contexts ()
 {
   descend_to_bottom_context ();
-  Simple_music_iterator::construct_children ();
+  Simple_music_iterator::create_contexts ();
 }
 
 void
 Event_iterator::process (Moment m)
 {
-  if (last_processed_mom_ < Moment (0))
+  if (!has_started ())
     report_event (get_music ());
 
   Simple_music_iterator::process (m);
